utils

package
v1.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 21, 2023 License: MIT Imports: 2 Imported by: 0

Documentation

Overview

Tis package contains the utility functions Helper - a function that printing a Warnings message logger - a function that setups the logger

Tis package contains the utility functions Helper - a function that printing a Warnings message logger - a function that setups the logger

Index

Examples

Constants

This section is empty.

Variables

This section is empty.

Functions

func Helper

func Helper(name string)
Example
package main

import (
	"github.com/Avdushin/gogger/Examples/App_example/utils"
)

func main() {
	utils.Helper("emenem")

}
Output:
2023/12/21 03:19:03 [WARNING] Emenem

func Logger

func Logger() *lib.Logger

Types

This section is empty.

Jump to