logger

package
v1.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 21, 2023 License: MIT Imports: 2 Imported by: 0

Documentation

Overview

The logger package contains the implementation of core logging methods

The logger package contains the implementation of core logging methods

Index

Constants

This section is empty.

Variables

Log - глобальная переменная логгера

Functions

func Debug

func Debug(format string, args ...interface{})

Debug записывает лог уровня DEBUG

func Error

func Error(format string, args ...interface{})

Error записывает лог уровня ERROR

func Info

func Info(format string, args ...interface{})

Info записывает лог уровня INFO

func InitLogger

func InitLogger(args ...interface{}) *lib.Logger

@ Инициализация логгера

func Warning

func Warning(format string, args ...interface{})

Warning записывает лог уровня WARNING

Types

This section is empty.

Jump to